traitsui\.tests package
=======================

Subpackages
-----------

.. toctree::

    traitsui.tests.editors
    traitsui.tests.null_backend
    traitsui.tests.ui_editors

Submodules
----------

.. toctree::

   traitsui.tests.test_actions
   traitsui.tests.test_color_column
   traitsui.tests.test_controller
   traitsui.tests.test_handler
   traitsui.tests.test_labels
   traitsui.tests.test_layout
   traitsui.tests.test_regression
   traitsui.tests.test_shadow_group
   traitsui.tests.test_splitter_prefs_restored
   traitsui.tests.test_toolkit
   traitsui.tests.test_tuple_editor
   traitsui.tests.test_ui
   traitsui.tests.test_visible_when_layout

Module contents
---------------

.. automodule:: traitsui.tests
    :members:
    :undoc-members:
    :show-inheritance:
